==> gbdxtools-0.6.7.tar.gz: gbdxtools-0.6.7/gbdxtools/task_registry.py <==
"""
GBDX Task Registry interface.

Contact: dmitry.zviagintsev@digitalglobe.com
"""

import json


class TaskRegistry(object):
    def __init__(self, interface):
        self._base_url = 'https://geobigdata.io/workflows/v1/tasks'

        # store a reference to the GBDX Connection
        self.gbdx_connection = interface.gbdx_connection

        # store a ref to the s3 interface
        self.s3 = interface.s3

        # the logger
        self.logger = interface.logger

    def list(self):
        """Lists available and visible GBDX tasks.

        Returns:
            List of tasks
        """
        r = self.gbdx_connection.get(self._base_url)
        r.raise_for_status()

        return r.json()['tasks']

    def register(self, task_json=None, json_filename=None):
        """Registers a new GBDX task.

        Args:
            task_json (dict): Dictionary representing task definition.
            json_filename (str): A full path of a file with json representing the task definition.
            Only one out of task_json and json_filename should be provided.
        Returns:
            Response (str).
        """
        if not task_json and not json_filename:
            raise Exception("Both task json and filename can't be none.")

        if task_json and json_filename:
            raise Exception("Both task json and filename can't be provided.")

        if json_filename:
            task_json = json.load(open(json_filename, 'r'))

        r = self.gbdx_connection.post(self._base_url, json=task_json)
        r.raise_for_status()

        return r.text

    def get_definition(self, task_name):
        """Gets definition of a registered GBDX task.

        Args:
            task_name (str): Task name.

        Returns:
            Dictionary representing the task definition.
        """
        r = self.gbdx_connection.get(self._base_url + '/' + task_name)
        r.raise_for_status()

        return r.json()

    def delete(self, task_name):
        """Deletes a GBDX task.

        Args:
            task_name (str): Task name.

        Returns:
            Response (str).
        """
        r = self.gbdx_connection.delete(self._base_url + '/' + task_name)
        r.raise_for_status()

        return r.text

==> gbdxtools-0.11.9.tar.gz: gbdxtools-0.11.9/gbdxtools/task_registry.py <==
"""
GBDX Task Registry interface.

Contact: dmitry.zviagintsev@digitalglobe.com
"""

import json
from gbdxtools.auth import Auth
from gbdxtools.s3 import S3

class TaskRegistry(object):
    def __init__(self, **kwargs):
        interface = Auth(**kwargs)
        self._base_url = '%s/workflows/v1/tasks' % interface.root_url

        # store a reference to the GBDX Connection
        self.gbdx_connection = interface.gbdx_connection

        # store a ref to the s3 interface
        self.s3 = S3()

        # the logger
        self.logger = interface.logger

    def list(self):
        """Lists available and visible GBDX tasks.

        Returns:
            List of tasks
        """
        r = self.gbdx_connection.get(self._base_url)
        r.raise_for_status()

        return r.json()['tasks']

    def register(self, task_json=None, json_filename=None):
        """Registers a new GBDX task.

        Args:
            task_json (dict): Dictionary representing task definition.
            json_filename (str): A full path of a file with json representing the task definition.
            Only one out of task_json and json_filename should be provided.
        Returns:
            Response (str).
        """
        if not task_json and not json_filename:
            raise Exception("Both task json and filename can't be none.")

        if task_json and json_filename:
            raise Exception("Both task json and filename can't be provided.")

        if json_filename:
            task_json = json.load(open(json_filename, 'r'))

        r = self.gbdx_connection.post(self._base_url, json=task_json)
        r.raise_for_status()

        return r.text

    def get_definition(self, task_name):
        """Gets definition of a registered GBDX task.

        Args:
            task_name (str): Task name.

        Returns:
            Dictionary representing the task definition.
        """
        r = self.gbdx_connection.get(self._base_url + '/' + task_name)
        r.raise_for_status()

        return r.json()

    def delete(self, task_name):
        """Deletes a GBDX task.

        Args:
            task_name (str): Task name.

        Returns:
            Response (str).
        """
        r = self.gbdx_connection.delete(self._base_url + '/' + task_name)
        r.raise_for_status()

        return r.text

    def update(self, task_name, task_json):
        """Updates a GBDX task.

        Args:
            task_name (str): Task name.
            task_json (dict): Dictionary representing updated task definition.

        Returns:
            Dictionary representing the updated task definition.
        """
        r = self.gbdx_connection.put(self._base_url + '/' + task_name, json=task_json)
        r.raise_for_status()

        return r.json()
